@@ -35,7 +35,7 @@ func TestBuildPackageGo117(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			t.Parallel()
 			fset := token.NewFileSet()
-			f, err := parser.ParseFile(fset, "p.go", tc.src, parser.ParseComments)
+			f, err := parser.ParseFile(fset, "p.go", tc.src, parser.ParseComments|parser.SkipObjectResolution)
 			if err != nil {
 				t.Error(err)
 			}
